@@ -27,7 +27,7 @@
 #' ## [1] "ppt" "ppt" "ppt"
 #' 
 #' pd_to_file(pd[1])
-#' ## [1] "C:/prismdir/PRISM_ppt_stable_4kmM3_2000_bil/PRISM_ppt_stable_4kmM3_2000_bil.bil""
+#' ## [1] "C:/prismdir/PRISM_ppt_stable_4kmM3_2000_bil/PRISM_ppt_stable_4kmM3_2000_bil.bil"
 #' }
 #' 
 #' @export
@@ -57,10 +57,20 @@ pd_get_date <- function(pd) {
 #' @export
 #' @rdname pd_get
 pd_get_type <- function(pd) {
-  p <- stringr::str_remove(pd, "PRISM_")
-  p <- stringr::str_split(p, "_", simplify = TRUE)
   
-  p[,1]
+  vapply(pd, function(x) {
+    web_service_version <- ifelse(grepl("PRISM", x), "v1", "v2")
+    if (web_service_version == 'v1'){
+      p <- stringr::str_remove(x, "PRISM_")
+      p <- stringr::str_split(p, "_", simplify = TRUE)
+      return(p[,1])
+    }
+    if (web_service_version == 'v2'){
+      parts <- strsplit(x, "_")[[1]]
+      return(parts[2])
+    }
+  }, character(1), USE.NAMES = FALSE)
+  
 }
 
 #' @description 
@@ -99,6 +109,8 @@ prism_md <- function(f, returnDate = FALSE) {
 #' @noRd
 
 pr_parse <- function(p,returnDate = FALSE){
+  ## Get webservice version of file
+  web_service_version = ifelse(p[1]=='PRISM', 'v1', 'v2')
   ## Extract the climate variable
   type <- p[2]
   ## Extract the date the data is for
@@ -130,7 +142,7 @@ pr_parse <- function(p,returnDate = FALSE){
     normals <- TRUE
   } else {
    
-    d <- p[length(p)-1]
+    d <- ifelse(web_service_version=='v1', p[length(p)-1], p[length(p)])
     yr <- substr(d,1,4)
     mon <- substr(d,5,6)
     day <- substr(d,7,8)
@@ -144,11 +156,23 @@ pr_parse <- function(p,returnDate = FALSE){
     )
   }
   
-  ures <- ifelse(
-    grepl("4km",paste(p,collapse="")),
-    "4km resolution",
-    "800m resolution"
-  )
+  if (web_service_version == 'v1'){
+    ures <- ifelse(
+      grepl("4km",paste(p,collapse="")),
+      "4km resolution",
+      "800m resolution"
+    )
+  } else {
+    ures <- ifelse(
+      grepl("25m",paste(p,collapse="")),
+      "4km resolution",
+      ifelse(
+        grepl("30s",paste(p,collapse="")),
+        "800m resolution",
+        "400m resolution"
+      )
+    )
+  }
   
   type <- prism_var_names(normals = normals)[type]
 
