@@ -1,12 +1,24 @@
 test_that("pd_stack() works", {
   # three days
-  dd <- prism_archive_subset("ppt", "daily", mon = 1, years = 1981:2011)
+  expect_warning(
+    dd <- prism_archive_subset(
+      "ppt", 
+      "daily", 
+      mon = 1, 
+      years = 1981:2011, 
+      resolution = '4km'
+    )
+  )
   expect_s4_class(x <- pd_stack(dd), "RasterStack")
   expect_equal(dim(x)[3], length(dd))
   expect_setequal(names(x), dd)
   
   # 2 months
-  mm <- prism_archive_subset("tdmean", "monthly", years = 2005)
+  expect_warning(
+    mm <- prism_archive_subset(
+      "tdmean", "monthly", years = 2005, resolution = '4km'
+    )
+  )
   expect_s4_class(x <- pd_stack(mm), "RasterStack")
   expect_equal(dim(x)[3], length(mm))
   expect_setequal(names(x), mm)
